summaryrefslogtreecommitdiffstats
path: root/Modules/xxlimited.c
diff options
context:
space:
mode:
authorBrett Simmers <swtaarrs@users.noreply.github.com>2024-05-03 15:30:55 (GMT)
committerGitHub <noreply@github.com>2024-05-03 15:30:55 (GMT)
commitc2627d6eea924daf80f374c18a5fd73ef61283fa (patch)
tree91d94d70f490562b2773aadb49b8befee6354f75 /Modules/xxlimited.c
parent3e818afb9b7c557aa633aeb3d5c4959750feeab0 (diff)
downloadcpython-c2627d6eea924daf80f374c18a5fd73ef61283fa.zip
cpython-c2627d6eea924daf80f374c18a5fd73ef61283fa.tar.gz
cpython-c2627d6eea924daf80f374c18a5fd73ef61283fa.tar.bz2
gh-116322: Add Py_mod_gil module slot (#116882)
This PR adds the ability to enable the GIL if it was disabled at interpreter startup, and modifies the multi-phase module initialization path to enable the GIL when loading a module, unless that module's spec includes a slot indicating it can run safely without the GIL. PEP 703 called the constant for the slot `Py_mod_gil_not_used`; I went with `Py_MOD_GIL_NOT_USED` for consistency with gh-104148. A warning will be issued up to once per interpreter for the first GIL-using module that is loaded. If `-v` is given, a shorter message will be printed to stderr every time a GIL-using module is loaded (including the first one that issues a warning).
Diffstat (limited to 'Modules/xxlimited.c')
-rw-r--r--Modules/xxlimited.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/Modules/xxlimited.c b/Modules/xxlimited.c
index 3357b80..d86741e 100644
--- a/Modules/xxlimited.c
+++ b/Modules/xxlimited.c
@@ -62,10 +62,10 @@
pass
*/
// Need limited C API version 3.12 for Py_MOD_PER_INTERPRETER_GIL_SUPPORTED
#include "pyconfig.h" // Py_GIL_DISABLED
#ifndef Py_GIL_DISABLED
-# define Py_LIMITED_API 0x030c0000
+# define Py_LIMITED_API 0x030d0000
#endif
#include "Python.h"
@@ -395,6 +395,7 @@ xx_modexec(PyObject *m)
static PyModuleDef_Slot xx_slots[] = {
{Py_mod_exec, xx_modexec},
{Py_mod_multiple_interpreters, Py_MOD_PER_INTERPRETER_GIL_SUPPORTED},
+ {Py_mod_gil, Py_MOD_GIL_NOT_USED},
{0, NULL}
};
@@ -62,10 +62,10 @@
pass
*/
-// Need limited C API version 3.12 for Py_MOD_PER_INTERPRETER_GIL_SUPPORTED
+// Need limited C API version 3.13 for Py_mod_gil
#include "pyconfig.h" // Py_GIL_DISABLED
#ifndef Py_GIL_DISABLED